@@ -39,6 +39,7 @@ from iai_common.communications.isp import ScenarioParameters as isp_ScenarioPara
 import collections
 
 Resolution = collections.namedtuple('Resolution', ['width', 'height'])
+CARLA_WEATHERS = ['ClearNoon', 'SoftRainNoon', 'HardRainNoon','ClearSunset', 'WetCloudySunset', 'SoftRainSunset']
 
 class Res:
     """
@@ -298,9 +299,13 @@ def build_initialize(builder, scenario, scenario_parameters=None,
     if world_parameters is not None:
         if 'carlatown' in world_parameters:
             carlatown = builder.CreateString(world_parameters['carlatown'])
+        if 'weather' in world_parameters:
+            weather = builder.CreateString(world_parameters['weather'])
         isp_WorldParameters.WorldParametersStart(builder)
         if 'carlatown' in world_parameters:
             isp_WorldParameters.WorldParametersAddCarlatown(builder, carlatown)
+        if 'weather' in world_parameters:
+            isp_WorldParameters.WorldParametersAddWeather(builder, weather)
         if 'traffic_count' in world_parameters:
             isp_WorldParameters.WorldParametersAddTrafficCount(builder, world_parameters['traffic_count'])
         if 'pedestrian_count' in world_parameters:
@@ -333,6 +338,8 @@ def unpack_initialize(message_body):
         world_parameters = {}
         if message_body.WorldParameters().Carlatown() is not None:
             world_parameters['carlatown'] = message_body.WorldParameters().Carlatown().decode("utf-8")
+        if message_body.WorldParameters().Weather() is not None:
+            world_parameters['weather'] = message_body.WorldParameters().Weather().decode("utf-8")
         if message_body.WorldParameters().TrafficCount() is not None:
             world_parameters['traffic_count'] = message_body.WorldParameters().TrafficCount()
         if message_body.WorldParameters().PedestrianCount() is not None:
